# MorphoNet


This is an API is used to interact with MorphoNet with python script.
You can find more help and tutorials on the MorphoNet website : http://www.morphonet.org

## Installation
This API work on python 3.7
You can simply install the MorphoNet API using   `pip install morphonet`

### Dependencies
The package will automatically install some dependencies :
* [numpy](https://pypi.org/project/numpy/)
* [scikit-image](https://pypi.org/project/scikit-image/)
* [scipy](https://pypi.org/project/scipy/) 
* [vtk](https://pypi.org/project/vtk/) (to convert the segmentation in meshes)
* [request](https://pypi.org/project/requests/) (to interrogate the morphonet server)
* [imageio](https://pypi.org/project/imageio/) (for Image Handling)
* [nibabel](https://pypi.org/project/nibabel/) (to load and save in nii format)


